;
;==========================================================================
;
; FILE: ufgatespace.pro
;
; USAGE:  result = UFgatespace(ufbuf, field)
;         ARGUMENTS  ufbuf  Buffer of UF words for a dwell of radar data
;                    field  Logical number of the data field
;
; ABSTRACT: Return the spacing between range gates in meters for the Nth
;           data field in the UF dwell buffer
;           For EDOP this is the same as the gate length
;
; AUTHOR:  I. Jeff Caylor
;          Science Systems and Applications, Inc.
;          5900 Princess Garden Parkway, Suite 300
;          Lanham, MD  20706
;
;     at:  NASA Goddard Space Flight Center
;          Code 912
;          Greenbelt, MD 20771
;          Voice: (301) 286-3767
;          Fax:   (301) 286-1762
;          Email: jeff.caylor@gsfc.nasa.gov
;
; CREATED: 7 April 1995
;
; MODIFIED:
;
;==========================================================================
;

;
; Return the gate spacing in meters for the Nth field
; Error = -1
;
FUNCTION UFgatespace, dwell, n
  d = UFfieldhdr(dwell, n)
  IF (d EQ -1) THEN  BEGIN
    RETURN, -1
  ENDIF
  a = dwell(d + 4)
  IF a LE 500 THEN BEGIN
     RETURN, float(a) 
;     PRINT, '*** inside ufgatespace:', float(a)
  ENDIF ELSE BEGIN
     RETURN, float(a)/64.0 ; for EDOP new data with over sampling
;     PRINT, '*** inside ufgatespace:', float(a)/64.0
  ENDELSE
END
