;
;==========================================================================
;
; FILE: ufnameddata.pro
;
; USAGE:  UFnameddata, ufbuf, fname, data, ngates, ERROR=error
;         ARGUMENTS  ufbuf   Buffer of UF words for a dwell of radar data
;                    fname   2 character ASCII name of the field
;                    data    Vector of scaled data in physical units
;                    ngates  Number of range gates in data-vectory
;                    ERROR   Optional return status
;                            0 = Success, Nonzero = Error
;
; ABSTRACT: Extract and return scaled data in physical units from the UF
;           dwell buffer for the named data field
;
; AUTHOR:  I. Jeff Caylor
;          Science Systems and Applications, Inc.
;          5900 Princess Garden Parkway, Suite 300
;          Lanham, MD  20706
;
;     at:  NASA Goddard Space Flight Center
;          Code 912
;          Greenbelt, MD 20771
;          Voice: (301) 286-3767
;          Fax:   (301) 286-1762
;          Email: jeff.caylor@gsfc.nasa.gov
;
; CREATED: 7 April 1995
;
; MODIFIED:
;
;==========================================================================
;

;
; Extract scaled data from the named field
; ERROR = 0 if successful, nozero otherwise
;
PRO UFnameddata, dwell, fname, data, ngates, ERROR=error
  error = -1
  field = UFfieldnumber(dwell, fname)
  IF (field NE -1) THEN $
    UFdata, dwell, field, data, ngates, ERROR=error
  RETURN
END

