;
;==========================================================================
;
; FILE: ufedop_longitude.pro
;
; USAGE:  result = UFedop_longitude(ufbuf)
;         ARGUMENT  ufbuf   Buffer of UF words for a dwell of radar data
;
; ABSTRACT: Return the longitude in degrees from the EDOP Local Use header
;           for the airfield
;
; AUTHOR:  I. Jeff Caylor
;          Science Systems and Applications, Inc.
;          5900 Princess Garden Parkway, Suite 300
;          Lanham, MD  20706
;
;     at:  NASA Goddard Space Flight Center
;          Code 912
;          Greenbelt, MD 20771
;          Voice: (301) 286-3767
;          Fax:   (301) 286-1762
;          Email: jeff.caylor@gsfc.nasa.gov
;
; CREATED: 7 April 1995
;
; MODIFIED:
;
;==========================================================================
;

;
; Return EDOP airfield longitude in degrees
;
FUNCTION UFedop_longitude, dwell
  i = UFlocalhdr(dwell)
  deg = float(dwell(i + 11))
  deg = deg + float(dwell(i + 12)) / 60.0 
  deg = deg + float(dwell(i + 13)) / 230400.0
  RETURN, deg
END
