;
;==========================================================================
;
; FILE: uffieldname_list.pro
;
; USAGE:  UFfieldname_list, ufbuf, list, nfields
;         ARGUMENTS  ufbuf    Buffer of UF words for a dwell of radar data
;                    list     Array of 2 character strings
;                    nfields  Number of names in the list
;
; ABSTRACT: Return a list of ASCII field names from the current UF dwell 
;           buffer
;
; AUTHOR:  I. Jeff Caylor
;          Science Systems and Applications, Inc.
;          5900 Princess Garden Parkway, Suite 300
;          Lanham, MD  20706
;
;     at:  NASA Goddard Space Flight Center
;          Code 912
;          Greenbelt, MD 20771
;          Voice: (301) 286-3767
;          Fax:   (301) 286-1762
;          Email: jeff.caylor@gsfc.nasa.gov
;
; CREATED: 7 April 1995
;
; MODIFIED:
;
;==========================================================================
;

;
; Build a string array containing a list of the ASCII field names
; Return the list and the number of fields
;
PRO UFfieldname_list, dwell, list, n
  n = UFfields(dwell)
  IF n GT 0 THEN BEGIN
    list = STRARR(n)  
    FOR f = 0, n - 1 DO list(f) = UFfieldname(dwell, f + 1)
  ENDIF
  RETURN
END
