;
;==========================================================================
;
; FILE: ufstarttime.pro
;
; USAGE:  result = UFstarttime(ufbuf)
;         ARGUMENTS  ufbuf  Buffer of UF words for a radar dwell
;
; ABSTRACT: Return the volume start time in decimal hours from a UF dwell
;           For EDOP this may be used as a flight leg start time
;
; AUTHOR:  I. Jeff Caylor
;          Science Systems and Applications, Inc.
;          5900 Princess Garden Parkway, Suite 300
;          Lanham, MD  20706
;
;     at:  NASA Goddard Space Flight Center
;          Code 912
;          Greenbelt, MD 20771
;          Voice: (301) 286-3767
;          Fax:   (301) 286-1762
;          Email: jeff.caylor@gsfc.nasa.gov
;
; CREATED: 7 April 1995
;
; MODIFIED:
;
;==========================================================================
;

;
; Return the volume start time in decimal hours
;
FUNCTION UFstarttime, dwell
  d = UFoptionalhdr(dwell)
  hour = float(dwell(d + 6))
  hour = hour + float(dwell(d + 7)) / 60.0
  hour = hour + float(dwell(d + 8)) / 3600.0
  RETURN, hour
END
