;
;==========================================================================
;
; FILE: ufinfo_demo.pro
;
; USAGE: ufinfo_demo, filename
;        ARGUMENTS    filename   Name of UF disk file
;
; ABSTRACT:  Demonstration program to open a EDOP UF file and display some
;            of the header information
;
; AUTHOR:  I. Jeff Caylor
;          Science Systems and Applications, Inc.
;          5900 Princess Garden Parkway, Suite 300
;          Lanham, MD  20706
;
;     at:  NASA Goddard Space Flight Center
;          Code 912
;          Greenbelt, MD 20771
;          Voice: (301) 286-3767
;          Fax:   (301) 286-1762
;          Email: jeff.caylor@gsfc.nasa.gov
;
; CREATED: 10 April 1995
;
; MODIFIED:
;          3 November 1999 - GMH
;          Added NORDSS option for reading NCAR files
;==========================================================================
;
PRO ufinfo_demo, filename, NORDSS = nordss

  OPENR, infile, filename, /GET_LUN
;
; Read first dwell
;
  IF KEYWORD_SET(NORDSS) THEN $
     UF_read_dwell, infile, ufbuf $
     ELSE UF_read_dwell, infile, ufbuf, /RDSS 
  CLOSE, infile
  FREE_lun, infile
;
; Get the available field names
;
  UFfieldname_list, ufbuf, list, nfields
;
;   Display UF information
;
  PRINT, ' '
  PRINT, 'File: ', filename, '        Radar: ', UFradar(ufbuf);
  PRINT, 'Date: ', UFstrdate(ufbuf), '    Time: ', UFstrtime(ufbuf);
  PRINT, 'Data fields: ', list
  PRINT, FORMAT='("Gates: ", I3)', UFgates(ufbuf, 1)
;
  PRINT, 'ER-2 '
  PRINT, FORMAT='("  Latitude: ", F10.6, "    Longitude: ", F10.6)', $
         UFedop_hybrid_latitude(ufbuf), UFedop_hybrid_longitude(ufbuf)
  PRINT, FORMAT='("  Altitude: ", I5, "    Heading: ", F7.2)', $
         UFedop_hybrid_altitude(ufbuf), UFedop_hybrid_heading(ufbuf)
END
