;
;==========================================================================
;
; FILE: uf_rangevec.pro
;
; USAGE:  result = UF_rangevec(ufbuf, field)
;         ARGUMENTS  ufbuf  Buffer of UF words for a dwell of radar data
;                    field  Logical number of the data field
;
; ABSTRACT: Return a range vector for the Nth data field in units of
;           kilometers
;
; AUTHOR:  I. Jeff Caylor
;          Science Systems and Applications, Inc.
;          5900 Princess Garden Parkway, Suite 300
;          Lanham, MD  20706
;
;     at:  NASA Goddard Space Flight Center
;          Code 912
;          Greenbelt, MD 20771
;          Voice: (301) 286-3767
;          Fax:   (301) 286-1762
;          Email: jeff.caylor@gsfc.nasa.gov
;
; CREATED: 12 April 1995
;
; MODIFIED:
;
;==========================================================================
;

;
; Return the range vector for the Nth data field
;
FUNCTION uf_rangevec, ufbuf, field
    rangevec = findgen(UFgates(ufbuf, field))
    rangevec = rangevec * UFgatespace(ufbuf, field) * 1.0e-3
    rangevec = rangevec + UFrangezero(ufbuf, field)
  RETURN, rangevec
END
